/* Table CSS. */
th {
    text-align: left;
}

.coord {
    font-size: 90%;
    border: 1px solid #999;
    color: #aaa;
}

.instructions {
    border: 1px solid #ccc;
    padding: 2px;
    margin: 8px;
}
.instructions p {
    margin: 0;
    background: #e9e9e9;
}
.breadcrumbs a, .thiscrumb {
    text-decoration: none;
    font-weight: bold;
    font-size: 90%;
}

.instructions {
    margin: 10px;
    font-weight: bold;
}

/* Slideshow controls. */
.slideControls {
    text-align: center;
    margin: 5px;
}
.slideControls a {
    margin: 2px;
    padding: 3px;
}
.slideControls a:hover {
    background: #ebeff0;
    padding: 2px;
    border: 1px solid #ccc;
}

/* Gallery Group view. */
#galleryGroups {
    width: 100%;
}
#galleryGroups table {
    border-collapse: collapse;
}
#galleryGroups td {
    margin: 0;
}
.galleryGroupsTile {
    padding: 1em;
}

/* Main view containers */
#ansel-contentwrapper {
    width: 100%;
    float: right;
}
#ansel-content {
    vertical-align: top;
    margin-left: 5px;
    margin-right: 255px;
}
#ansel-widgetcontent {
    float: right;
    width: 250px;
    margin-left: 5px;
    margin-right: -100%;
    margin-top: 5px;
    vertical-align: top;
}
#ansel-content-nowidgets {
  vertical-align: top;
}

/* Image view */
#anselimagecontainer, #Photo {
    text-align: center;
}
#anselcaptioncontainer, #CaptionContainer {
    margin: 0 auto;
    text-align: left;
    font-size: 125%;
}
#anselcaption, #Caption {
    padding: 1em;
}

#sortContainer {
    margin: 10px;
    border: 1px solid #ccc;
}
#sortContainer div {
    cursor: move;
    margin: 10px;
    height: 170px;
    float: left;
}
#sortContainer a {
    cursor: move;
}

/* Widgets container*/
.anselWidgets {
    margin-right: 5px;
    vertical-align: top;
}
.anselWidgets .header {
    background: none;
    color: #333333;
}
.anselWidgets .header a {
    color: #333333;
}
.anselWidgets img {
    padding: 1px;
}

/* Widget blocks */
.anselWidget {
    border: 1px solid #ccc;
    padding: 4px;
}
.anselWidget .control {
    background: #eee;
    text-align: center;
    border: 0;
}
.anselWidget {
    padding: 4px;
}

/* Specific widgets */
.ansel-embedlink {
   border-top: 1px solid #ccc;
}
.ansel-embedlink textarea {
    color: #aaa;
    width: 100%;
    resize: none;
    overflow: auto;
}

.tagTitle {
    font-size: 100%;
    border: none;
}
#tags {
    padding: 4px;
}
#tags form {
    white-space: nowrap;
    margin-top: 4px;
}
#gallery-actions a:hover {
    text-decoration: underline;
}
#gallery-actions a.widget {
    color: #000;
    white-space: normal;
}
#gallery-actions-toggle.show, #othergalleries-toggle.show {
    background: url('graphics/down.png') center center no-repeat;
    display: block;
    padding-left: 15px;
}
#gallery-actions-toggle.hide, #othergalleries-toggle.hide {
    background: url('graphics/up.png') center center no-repeat;
    display: block;
    padding-left: 15px;
}
#gallery-actions-toggle:hover, #othergalleries-toggle:hover {
    text-decoration: none;
}
#othergalleries .horde-tree-row img {
    margin: 5px;
}

a.earliest:link, a.earliest:visited, a.earliest:hover, a.earliest:active {
    color: #ccc;
}

a.earlier:link, a.earlier:visited, a.earlier:hover, a.earlier:active {
    color: #99c;
}

a.later:link, a.later:visited, a.later:hover, a.later:active {
    color: #99f;
}

a.latest:link, a.latest:visited, a.latest:hover, a.latest:active {
    color: #00f;
}

#ansel_preview {
    position: absolute;
}

/* Face recognition/detection rules */
.face-tile {
    height: 100px;
    margin: 5px;
    float: left;
}
.face-div {
    position:absolute;
}
.face-div-name {
    text-align: center;
    background: grey;
    color: white;
}
.shown {
    border: medium solid white;
}

.similarity-high {
    color: red;
}
.similarity-medium {
    color: green;
}
.similarity-low {
    color: #ffcc00;
}
.similarity-lower {
    color: #cccccc;
}
.bordered-facethumb {
    border: 1px solid black;
    margin: 2px;
    float: left;
}

.ansel-tile {
    padding-top: 10px;
    text-align: center;
}

/* Gallery styles */
.gallery-desc {
    background: #fff;
}

/* Gallery tiles */
.gallery-tile-caption {
    margin: 0;
    padding: 0;
    font-weight: bold;
    font-size: 100%;
}
.gallery-tile p {
    margin: 0;
    padding: 0;
}

/* Image tiles */
.image-tile-caption {
    display: block;
    font-size: 90%;
    padding: .2em;
}
.ansel-tile img {
    padding: 3px;
}
.image-tile-highlight {
    background-color: #ccc;
}

/* Exif data */
#ansel-exif-table {
  width: 100%;
}

/* Actions */
.anselActions {
    /*border: 1px #cccccc solid;*/
}
.anselActions a, .anselActions a:visited, .anselActions label {
    white-space: nowrap;
}
.anselActions a img {
    padding-left: 2px;
    padding-right: 2px;
}

/* Image resizer/slider */
#slider-track {
    background: url('graphics/scaler_slider_track.gif') no-repeat;
    width:200px;
/*    margin:10px 0; */
    position: relative;
    height:18px;
    margin: 4px auto 4px auto;
}

.sliderHandle {
    cursor: move;
    position: absolute;
    width: 18px;
    height: 18px;
}

/* Icons. */
.ansel-browse {
  background-image: url('graphics/browse.png');
}
.ansel-mygalleries {
  background-image: url('graphics/galleries.png');
}
.ansel-allgalleries {
  background-image: url('graphics/allgalleries.png');
}
.ansel-faces {
  background-image: url('graphics/faces.png');
}

 /* Map */
#ansel_map {
    width:100%;
    height:250px;
    overflow:hidden;
    border-bottom: 1px solid #ccc;
}
#ansel_map_small {
    width:100%;
    height:80px;
    margin-top:10px;
    overflow:hidden;
    border-top: 1px solid #ccc;
}
.ansel_location_sameas {
    background-color: #979797;
    width: 100%;
}
.ansel_location_sameas img {
    border: 1px solid white;
    margin: 5px;
}
.ansel_geolocation {
    background: url(http://maps.gstatic.com/intl/en_us/mapfiles/marker.png) center left no-repeat;
    margin:10px 0 6px;
    padding:0 0 6px 30px;
    min-height: 37px;
}
#ansel_latlng {
    color:#666666;
    font-size:90%;
    white-space: nowrap;
    margin-right: 5px;
}

#ansel_locationtext {
    margin: 0;
    font-size: 80%;
}

#ansel_deleteGeotag {
    font-size: 70%;
    font-style: italic;
}

/* OL specific tweaks */
.olControlZoomPanel {
  top: 10px !important;
}

/* Autocomplete styles. */
.autocomplete {
    background: #f4f4f4;
    border: 1px solid #d4d4d4;
    position: absolute;
    padding: 2px 2px 2px 2px;
}
.autocomplete ul {
    margin: 1px;
    padding: 1px;
    list-style-type: none;
}
.autocomplete ul li {
    padding-top: 3px;
    padding-bottom: 3px;
    cursor: pointer;
    text-decoration: underline;
    font-size: 90%;
    color: #000;
}
.autocomplete ul .selected {
    background: gray;
    color: #fff;
}

/* Pluploader */
#anseluploader {
    width: auto;
    padding: 2px;
}
.uploaderContainer {
    border: solid 1px #999999;
    margin: 3px;
}
.uploadnotification {
  min-height: 20px;
  padding-left: 8px;
}

/* Horizontal Carousel */
#horizontal_carousel {
  float:left;
  width: 575px;
  height: 200px;
  margin-bottom: 10px;
  position: relative;
}

#horizontal_carousel .container {
  position: absolute;
  top: 5px;
  left: 37px;
  width: 504px;
  height: 144px;
  overflow:hidden;
  background: #3F3F3F;
}

#horizontal_carousel .previous_button {
  position: absolute;
  top: 5px;
  left: 10px;
  width: 27px;
  height: 144px;
  background: url("graphics/carousel/left.gif");
  z-index: 100;
  cursor:pointer;
}

#horizontal_carousel .previous_button_disabled {
  background: url("graphics/carousel/left-disabled.gif");
  cursor:default;
}

#horizontal_carousel .next_button {
  position: absolute;
  top: 5px;
  right: 10px;
  width: 27px;
  height: 144px;
  background: url("graphics/carousel/right.gif");
  z-index: 100;
  cursor:pointer;
}

#horizontal_carousel .next_button_disabled {
  background: url("graphics/carousel/right-disabled.gif");
  cursor:default;
}

#horizontal_carousel ul {
  margin: 0;
  padding:0;
  width: 100000px;
  position: relative;
  top: 0;
  left: 0;
  height: 144px;
}

#horizontal_carousel ul li img {
  border:1px solid #999999;
  display:block;
  background:#E3EDFA;
}

#horizontal_carousel ul li {
  font-family:verdana,arial,sans-serif;
  font-size:10px;
}

#horizontal_carousel ul li {
  border:0px solid green;
  color:#E3EDFA;
  margin:0pt;
  padding:15px 10px 10px;

  list-style:none;
  float:left;
}

#spinner {
    position: absolute;
    top: 0px;
    left: 50px;
    width: 100%;
    background: #FFF;
    z-index: 10;
    text-align: center;
    font-size: 150%;
    opacity: 0;
}
